/**
 * @file
 * @brief UART interface definition.
 */
#ifndef STA_CORE_UART_HPP
#define STA_CORE_UART_HPP

#include <cstddef>
#include <cstdint>


namespace sta
{
	/**
	 * @brief Interface for %UART.
	 */
	class UART
	{
	public:
		/**
		 * @brief Write buffer to %UART.
		 *
		 * @param buffer    Source buffer
		 * @param size      Number of bytes in buffer
		 */
		virtual void write(const uint8_t * buffer, size_t size) = 0;

		/**
		 * @brief Write unsigned integer to %UART.
		 *
		 * @param value     Unsigned integer value
		 */
		void write(uint8_t value);
		/**
		 * @brief Write unsigned integer to %UART.
		 *
		 * @param value     Unsigned integer value
		 */
		void write(uint16_t value);
		/**
		 * @brief Write unsigned integer to %UART.
		 *
		 * @param value     Unsigned integer value
		 */
		void write(uint32_t value);
	};
} // namespace sta


#endif // STA_CORE_UART_HPP
